summaryrefslogtreecommitdiffstats
path: root/unix
diff options
context:
space:
mode:
authormax <max@tclers.tk>2014-04-07 15:11:32 (GMT)
committermax <max@tclers.tk>2014-04-07 15:11:32 (GMT)
commitf83f7d140e5150b79aa714c448879448d51f5bf5 (patch)
tree06f8d77c7681f193855987537a54a1661294dcdb /unix
parent6ab79205ac7597fa0c7b84ef86c9e341b99bc8b6 (diff)
downloadtcl-f83f7d140e5150b79aa714c448879448d51f5bf5.zip
tcl-f83f7d140e5150b79aa714c448879448d51f5bf5.tar.gz
tcl-f83f7d140e5150b79aa714c448879448d51f5bf5.tar.bz2
Rename CreateClientSocket to TcpConnect
Diffstat (limited to 'unix')
-rw-r--r--unix/tclUnixSock.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/unix/tclUnixSock.c b/unix/tclUnixSock.c
index d4b7b62..f428811 100644
--- a/unix/tclUnixSock.c
+++ b/unix/tclUnixSock.c
@@ -110,7 +110,7 @@ struct TcpState {
* Static routines for this file:
*/
-static int CreateClientSocket(Tcl_Interp *interp,
+static int TcpConnect(Tcl_Interp *interp,
TcpState *state);
static void TcpAccept(ClientData data, int mask);
static int TcpBlockModeProc(ClientData data, int mode);
@@ -409,13 +409,13 @@ WaitForConnect(
if (noblock || (statePtr->flags & TCP_ASYNC_SOCKET)) {
if (TclUnixWaitForFile(statePtr->fds.fd,
TCL_WRITABLE | TCL_EXCEPTION, 0) != 0) {
- CreateClientSocket(NULL, statePtr);
+ TcpConnect(NULL, statePtr);
}
} else {
while (statePtr->flags & TCP_ASYNC_CONNECT) {
if (TclUnixWaitForFile(statePtr->fds.fd,
TCL_WRITABLE | TCL_EXCEPTION, -1) != 0) {
- CreateClientSocket(NULL, statePtr);
+ TcpConnect(NULL, statePtr);
}
}
}
@@ -936,7 +936,7 @@ TcpGetHandleProc(
*
* TcpAsyncCallback --
*
* Called by the event handler that CreateClientSocket sets up
* internally for [socket -async] to get notified when the
* asyncronous connection attempt has succeeded or failed.
*
@@ -949,13 +949,13 @@ TcpAsyncCallback(
* TCL_READABLE, TCL_WRITABLE and
* TCL_EXCEPTION. */
{
- CreateClientSocket(NULL, clientData);
+ TcpConnect(NULL, clientData);
}
/*
*----------------------------------------------------------------------
*
- * CreateClientSocket --
+ * TcpConnect --
*
* This function opens a new socket in client mode.
*
@@ -983,7 +983,7 @@ TcpAsyncCallback(
*/
static int
-CreateClientSocket(
+TcpConnect(
Tcl_Interp *interp, /* For error reporting; can be NULL. */
TcpState *statePtr)
{
@@ -1198,7 +1198,7 @@ Tcl_OpenTcpClient(
/*
* Create a new client socket and wrap it in a channel.
*/
- if (CreateClientSocket(interp, statePtr) != TCL_OK) {
+ if (TcpConnect(interp, statePtr) != TCL_OK) {
TcpCloseProc(statePtr, NULL);
return NULL;
}
@@ -936,7 +936,7 @@ TcpGetHandleProc(
* TcpAsyncCallback --
*
- * Called by the event handler that CreateClientSocket sets up
+ * Called by the event handler that TcpConnect sets up
* internally for [socket -async] to get notified when the
* asyncronous connection attempt has succeeded or failed.